<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Salon;
use App\Models\SalonBankTransfer;
use App\Models\UserTokens;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class TransfersController extends Controller
{
    public function index()
    {
        $rows = SalonBankTransfer::whereType('receive')->orderByDesc('id')->get();
         return view('admin.transfers.index', compact('rows'));
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'admin_approve' => 'required|in:accept,refuse'
        ]);
        SalonBankTransfer::where('id', $id)->update([
            'admin_approve' => $request['admin_approve']
        ]);
        $old = SalonBankTransfer::find($id);

        if ($request['admin_approve'] == 'accept') {
            SalonBankTransfer::create([
                'salon_id' => $old->salon_id,
                'type' => 'add',
                'admin_approve' => $request['admin_approve'],
                'amount' => $old->amount,
                'account_id' => $old->account_id,
                'parent_id' => $old->id,
                'code' => uniqid(),
            ]);
            $salon = Salon::find($old->salon_id);
            $salon->wallet += $old->amount;
            $salon->update();

            $tokens = UserTokens::where('user_id', $salon->user_id)->get();


            foreach ($tokens as $token) {

                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title' => 'تم تأكيد طلب تحويل المبلغ',
                            'body' => 'تم تأكيد طلب تحويل المبلغ',
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title' => 'تم تأكيد طلب تحويل المبلغ',
                            'body' => 'تم تأكيد طلب تحويل المبلغ',
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title' => 'تم تأكيد طلب تحويل المبلغ',
                            'body' => 'تم تأكيد طلب تحويل المبلغ',
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }


            }

        } elseif ($request['admin_approve'] == 'refuse') {
            $salon = Salon::find($old->salon_id);
            $tokens = UserTokens::where('user_id', $salon->user_id)->get();


            foreach ($tokens as $token) {

                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title' => 'تم رفض طلبكم بخصوص تحويل المبلغ',
                            'body' => 'تم رفض طلبكم بخصوص تحويل المبلغ',
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title' => 'تم رفض طلبكم بخصوص تحويل المبلغ',
                            'body' => 'تم رفض طلبكم بخصوص تحويل المبلغ',
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title' => 'تم رفض طلبكم بخصوص تحويل المبلغ',
                            'body' => 'تم رفض طلبكم بخصوص تحويل المبلغ',
                            'type' => 'admin',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }


            }

        }
        toast('تمت العملية بنجاح', 'success');
        return redirect()->back();
    }

    public function destroy($id)
    {
        SalonBankTransfer::destroy($id);
        toast('تم الحذف بنجاح', 'success');
        return redirect()->back();
    }
}
