<?php

namespace App\Http\Controllers\Api\Client;

use App\Http\Controllers\Controller;
use App\Http\Resources\OrderResource;
use App\Http\Resources\SmallOrderResource;
use App\Models\Notification;
use App\Models\Order;
use App\Models\OrderService;
use App\Models\Salon;
use App\Models\UserTokens;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use JWTAuth;

class OrdersController extends Controller
{

    public function order(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'order_place' => 'required|in:home,salon',
            'package_id' => 'nullable',
            'services' => 'required_if:package_id,nullable',
            'total_price' => 'required',
            'salon_id' => 'required'
        ]);

        if ($validator->passes()) {
            $order = new Order();
            $order['user_id'] = $user->id;
            $order['code'] = uniqid();
            $order['salon_id'] = $request['salon_id'];
            $order['package_id'] = $request['package_id'];
            $order['order_place'] = $request['order_place'];
            $order['total_price'] = $request['total_price'];
            $order['status'] = 'in_complete';
            $order->save();
            if ($request['services']) {
                foreach (explode(',', $request['services']) as $service) {
                    OrderService::create([
                        'order_id' => $order->id,
                        'service_id' => $service
                    ]);
                }
            }
            return response()->json(['value' => true, 'data' => (string)$order->id, 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }

    }

    public function complete_order(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [

            'lat' => 'required',
            'lng' => 'required',
            'address' => 'required',
            'order_date' => 'required',
            'order_time' => 'required',
            'payment_type' => 'required|in:visa,cash',
            'order_id' => 'required|exists:orders,id'
        ]);
        if ($validator->passes()) {
            $order = Order::find($request['order_id']);
            $order['lat'] = $request['lat'];
            $order['lng'] = $request['lng'];
            $order['address'] = $request['address'];
            $order['order_date'] = $request['order_date'];
            $order['order_time'] = $request['order_time'];
            $order['payment_type'] = $request['payment_type'];
            $order['status'] = 'waiting';
            $order->update();

            $salon = Salon::find($order->salon_id);
            $salon->order_counts += 1;
            $salon->update();
            $notification = new Notification();
            $notification['user_id'] = $salon->user_id;
            $notification['order_id'] = $order->id;
            $notification['body'] = 'لديكم طلب جديد';
            $notification['type'] = 'new_order';
            $notification['salon_id'] = $salon->id;
            $notification->save();

            if ($salon->receive_notifications == 'true'){

                $tokens = UserTokens::where('user_id', $salon->user_id)->where('status', 'connected')->get();

                foreach ($tokens as $token) {

                    $push = new PushNotification('fcm');

                    if ($token->device_type == 'ios') {
                        $msg = [
                            'data' => [
                                'title' => "لديكم طلب جديد",
                                'body' => "لديكم طلب جديد",
                                'type' => 'new_order',
                                'order_id' => $order->id,
                                'sound' => 'default',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'notification' => [
                                'title' => "لديكم طلب جديد",
                                'body' => "لديكم طلب جديد",
                                'type' => 'new_order',
                                'order_id' => $order->id,
                                'sound' => 'default',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    } else {
                        $msg = [
                            'data' => [
                                'title' => "لديكم طلب جديد",
                                'body' => "لديكم طلب جديد",
                                'type' => 'new_order',
                                'order_id' => $order->id,
                                'sound' => 'default',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();

                    }



                }
            }


            return response()->json(['value' => true, 'data' => 'تمت العمليه بنجاح و بإنتظار موافقه الصالون', 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 400]);
        }

    }

    public function cancel_order($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        Order::where('id', $id)->update([
            'status' => 'cancel'
        ]);
        return response()->json(['value' => true, 'data' => 'تم الإلغاء بنجاح', 'code' => 200]);
    }

    public function orders($flag)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $rows = Order::where('status', $flag)->where('user_id', $user->id)->where('status', '!=', 'in_complete')->paginate(20);
        return SmallOrderResource::collection($rows)->additional(['value' => true, 'code' => 200]);
    }
}
