<?php

namespace App\Http\Controllers\Api\Client;

use App\Http\Controllers\Controller;
use App\Http\Resources\SalonResource;
use App\Http\Resources\SlidersResource;
use App\Http\Resources\UserSalonResource;
use App\Models\Category;
use App\Models\OrderService;
use App\Models\Salon;
use App\Models\Service;
use App\Models\Slider;
use App\User;
use Illuminate\Http\Request;

class SalonsController extends Controller
{
    public function salons($flag = null)
    {


//        $flags = ['most_service','new_services','most_rates','low_price','high_price'];

        if ($flag == null) {
            $rows = Salon::whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->paginate(20);
        } elseif ($flag == 'most_service') {
            $ordered_services = OrderService::select('service_id')->groupBy('service_id')
                ->orderByRaw('COUNT(*) DESC')
                ->limit(1)
                ->get();
            $all_salons = [];

            foreach ($ordered_services as $item) {
                $all_salons[] = Service::where('id', $item->service_id)->value('salon_id');
            }
            if (count($all_salons) > 0) {
                $rows = Salon::whereHas('user', function ($user) {
                    $user->where('status', 'active')->where('admin_approve', 'true');
                })->whereIn('id', $all_salons)->paginate(20);
            } else {
                $rows = Salon::whereHas('user', function ($user) {
                    $user->where('status', 'active')->where('admin_approve', 'true');
                })->paginate(20);
            }

        } elseif ($flag == 'new_services') {
            $salons = Service::orderByDesc('id')->pluck('salon_id');
            $rows = Salon::whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->whereIn('id', $salons)->paginate(20);
        } elseif ($flag == 'most_rates') {
            $sorted = Salon::get()
                ->sortByDesc('total_rate')  //appended attribute
                ->pluck('id')
                ->toArray();
            $salons_ids = implode(',', $sorted);


            $rows = Salon::orderByRaw(\DB::raw("FIELD(id, " . $salons_ids . " )"))->whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->paginate(20);

        } elseif ($flag == 'low_price') {
            $salons = Service::orderByDesc('price')->pluck('salon_id');
            $rows = Salon::whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->whereIn('id', $salons)->paginate(20);
        } else {
            $salons = Service::orderBy('price', 'asc')->pluck('salon_id');
            $rows = Salon::whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->whereIn('id', $salons)->paginate(20);
        }

        return SalonResource::collection($rows)->additional(['value' => true, 'code' => 200]);


    }

    public function single_salon($id)
    {
        $row = Salon::find($id);
        $data = new SalonResource($row);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function single_user_salon($id)
    {
        $row = User::find($id);

        if ($row->salon){
            $data = new UserSalonResource($row);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        }else{
            return response()->json(['value'=>false,'msg'=>'عفوا الصالون غير مكتمل البيانات']);
        }


    }

    public function sliders()
    {
        $rows = Slider::all();
        return SlidersResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function search(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'search' => 'required'
        ]);
        if ($validator->passes()) {

            $rows = Salon::whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->where('salon_title', 'LIKE', '%' . $request['search'] . '%')->paginate(20);
            return SalonResource::collection($rows)->additional(['value' => true, 'code' => 200]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function filter_services(Request $request)
    {

        $filters_by = ['categories', 'city_id', 'rate', 'orders', 'price_from', 'price_to', 'discount', 'place'];
        $rows = Salon::whereHas('user', function ($user) {
            $user->where('status', 'active')->where('admin_approve', 'true');
        })->get();


        if ($request['categories'] != 0) {
            $salons = [];
            $categories = explode(',', $request['categories']);
            foreach ($categories as $category_id) {
                $category = Category::find($category_id);
                foreach ($category->salons as $salon) {
                    $salons[] = $salon->id;
                }
            }
            $salon_unique = array_unique($salons);
            $rows = Salon::whereHas('user', function ($user) {
                $user->where('status', 'active')->where('admin_approve', 'true');
            })->whereIn('id', $salon_unique)->get();


        }
        if ($request['city_id'] != 0) {
            $rows = $rows->where('city_id', $request['city_id']);
        }

        if ($request['rate']) {
            $rows = $rows->where('rate', '>=', $request['rate']);
        }

        if ($request['price_from'] && $request['price_to']) {

//             $rows->whereHas('services', function ($service) use ($request) {
//                $service->where('price', '>=', $request['price_from'])->where('price', '<=', $request['price_from']);
//            });
            $new_rows = [];
            foreach ($rows as $row) {
                foreach ($row->services as $service) {
                    if ($service->price >= $request['price_from'] && $service->price <= $request['price_to']) {
                        $new_rows[] = $service->salon;
                    }
                }
            }
            $rows = collect($new_rows);
        }
        if ($request['discount'] != 0) {
            $new_discounts = [];
            foreach ($rows as $row) {
                foreach ($row->services as $service) {
                    if ($service->discount_percent >= $request['discount']) {
                        $new_discounts[] = $service->salon;
                    }
                }
            }
            $rows = collect($new_discounts);
//            $rows->whereHas('services', function ($service) use ($request) {
//                $service->where('discount_percent', '>=', $request['discount']);
//            });
        }

        if ($request['place']) {

            $place = [];

            foreach ($rows as $row) {
                foreach ($row->services as $service) {
                    if ($service->place == $request['place']) {
                        $place[] = $service->salon;
                    }
                }
            }
            $rows = collect($place);
        }

        if ($request['order_counts'] != 0) {
            $rows = $rows->where('order_counts', '>=', $request['order_counts']);
        }

        $latest_salons = [];
        foreach ($rows as $new_row) {
            $latest_salons[] = $new_row->id;
        }

        $latest_salons_unique = array_unique($latest_salons);
        $farouz = [];
        foreach ($latest_salons_unique as $key => $value) {
            $farouz[] = $value;
        }
        $rows = Salon::whereIn('id', $farouz)->get();
        return SalonResource::collection($rows)->additional(['value' => true, 'code' => 200]);


    }
}
